The mplcursors API
==================

.. module:: mplcursors

|

.. autosummary::
   mplcursors.Cursor
   mplcursors.cursor
   mplcursors.HoverMode
   mplcursors.Selection
   mplcursors.compute_pick
   mplcursors.get_ann_text
   mplcursors.move
   mplcursors.make_highlight

|

.. autoclass:: mplcursors.Cursor
   :members:
   :special-members: __init__
   :undoc-members:

.. autofunction:: mplcursors.cursor

.. autoclass:: mplcursors.HoverMode
   :members:
   :undoc-members:

.. autoclass:: mplcursors.Selection
   :members:
   :undoc-members:

.. autofunction:: mplcursors.compute_pick
.. autofunction:: mplcursors.get_ann_text
.. autofunction:: mplcursors.move
.. autofunction:: mplcursors.make_highlight
